# generated by datamodel-codegen:
#   filename:  heart.json
#   timestamp: 2021-10-31T18:17:22+00:00

from __future__ import annotations

from typing import List

from pydantic import BaseModel, Field


class HeartRateZone(BaseModel):
    caloriesOut: float
    max: int
    min: int
    minutes: int
    name: str


class Value(BaseModel):
    customHeartRateZones: List
    heartRateZones: List[HeartRateZone]
    restingHeartRate: int


class ActivitiesHeartItem(BaseModel):
    dateTime: str
    value: Value


class DatasetItem(BaseModel):
    time: str
    value: int


class ActivitiesHeartIntraday(BaseModel):
    dataset: List[DatasetItem]
    datasetInterval: int
    datasetType: str


class HeartResponse(BaseModel):
    activities_heart: List[ActivitiesHeartItem] = Field(..., alias='activities-heart')
    activities_heart_intraday: ActivitiesHeartIntraday = Field(
        ..., alias='activities-heart-intraday'
    )
