# generated by datamodel-codegen:
#   filename:  distance.json
#   timestamp: 2021-10-31T18:17:23+00:00

from __future__ import annotations

from typing import List

from pydantic import BaseModel, Field


class ActivitiesDistanceItem(BaseModel):
    dateTime: str
    value: str


class DatasetItem(BaseModel):
    time: str
    value: float


class ActivitiesDistanceIntraday(BaseModel):
    dataset: List[DatasetItem]
    datasetInterval: int
    datasetType: str


class DistanceResponse(BaseModel):
    activities_distance: List[ActivitiesDistanceItem] = Field(
        ..., alias='activities-distance'
    )
    activities_distance_intraday: ActivitiesDistanceIntraday = Field(
        ..., alias='activities-distance-intraday'
    )
