# generated by datamodel-codegen:
#   filename:  refresh-token.json
#   timestamp: 2021-10-31T18:17:20+00:00

from __future__ import annotations

from typing import List

from pydantic import BaseModel


class RefreshTokenResponse(BaseModel):
    access_token: str
    expires_in: int
    refresh_token: str
    scope: List[str]
    token_type: str
    user_id: str
    expires_at: float
