from pathlib import Path

TESTS_FOLDER = Path(__file__).parent
INPUT_DATA_FOLDER = TESTS_FOLDER / "input_data"
RESPONSES_FOLDER = INPUT_DATA_FOLDER / "responses"
INTRADAY_RESPONSES_FOLDER = RESPONSES_FOLDER / "intraday"