# generated by datamodel-codegen:
#   filename:  steps.json
#   timestamp: 2021-10-31T18:17:22+00:00

from __future__ import annotations

from typing import List

from pydantic import BaseModel, Field


class ActivitiesStep(BaseModel):
    dateTime: str
    value: str


class DatasetItem(BaseModel):
    time: str
    value: int


class ActivitiesStepsIntraday(BaseModel):
    dataset: List[DatasetItem]
    datasetInterval: int
    datasetType: str


class StepsResponse(BaseModel):
    activities_steps: List[ActivitiesStep] = Field(..., alias='activities-steps')
    activities_steps_intraday: ActivitiesStepsIntraday = Field(
        ..., alias='activities-steps-intraday'
    )
